@@ -371,7 +371,7 @@
      (incf e (* nom ($euler %k)))
      (go a)))
 
-(defmfun simpeuler (x vestigial z)
+(defun simpeuler (x vestigial z)
   (declare (ignore vestigial))
   (oneargcheck x)
   (let ((u (simpcheck (cadr x) z)))
@@ -427,7 +427,7 @@
      (setq a (*red a b) b (denom1 a) a (num1 a))
      (go a)))
 
-(defmfun simpbern (x vestigial z)
+(defun simpbern (x vestigial z)
   (declare (ignore vestigial))
   (oneargcheck x)
   (let ((u (simpcheck (cadr x) z)))
@@ -453,7 +453,7 @@
 ;;; $zerobern is bound to true.
 ;;; ----------------------------------------------------------------------------
 
-(defun $bernpoly (x s)
+(defmfun $bernpoly (x s)
   (let ((%n 0) ($zerobern t))
     (cond ((not (fixnump s)) (list '($bernpoly) x s))
 	  ((> (setq %n s) -1)
@@ -487,7 +487,7 @@
 ;;; The coeffizients E[k] are the Euler numbers.
 ;;; ----------------------------------------------------------------------------
 
-(defun $eulerpoly (x s)
+(defmfun $eulerpoly (x s)
   (let ((n 0) ($zerobern t) (y 0))
     (cond ((not (fixnump s)) (list '($eulerpoly) x s))
           ((> (setq n s) -1)
@@ -516,7 +516,7 @@
 ;;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(defun $zeta (z)
+(defmfun $zeta (z)
   (simplify (list '(%zeta) z)))
 
 ;;; Set properties to give full support to the parser and display
@@ -642,7 +642,8 @@
     ((complex rational)
      (setf s (coerce s '(complex flonum)))))
 
-  (let ((sigma (bigfloat:realpart s)))
+  (let ((sigma (bigfloat:realpart s))
+        (tau (bigfloat:imagpart s)))
     (cond
       ;; abs(s)^2 < epsilon, use the expansion zeta(s) = -1/2-1/2*log(2*%pi)*s
       ((bigfloat:< (bigfloat:abs (bigfloat:* s s)) (bigfloat:epsilon s))
@@ -651,12 +652,13 @@
                                (bigfloat:log (bigfloat:* 2 (bigfloat:%pi s)))
                                s)))
 
-      ;; Reflection formula
-      ((bigfloat:minusp sigma)
+      ;; Reflection formula:
+      ;; zeta(s) = 2^s*%pi^(s-1)*sin(%pi*s/2)*gamma(1-s)*zeta(1-s)
+      ((not (bigfloat:plusp sigma))
        (let ((n (bigfloat:floor sigma)))
-	 ;; If sigma is a negative even integer, zeta(sigma) is zero,
-	 ;; from the reflection formula because sin(%pi*n/2) is 0.
-	 (when (and (bigfloat:= n sigma) (evenp n))
+	 ;; If s is a negative even integer, zeta(s) is zero,
+	 ;; from the reflection formula because sin(%pi*s/2) is 0.
+	 (when (and (bigfloat:zerop tau) (bigfloat:= n sigma) (evenp n))
 	   (return-from float-zeta (bigfloat:float 0.0 sigma))))
        (bigfloat:* (bigfloat:expt 2 s)
                    (bigfloat:expt (bigfloat:%pi s)
@@ -670,8 +672,7 @@
       ;; The general formula from above. Call the imaginary part "tau" rather
       ;; than the "t" above, because that isn't a CL keyword...
       (t
-       (let* ((tau (bigfloat:imagpart s))
-              (logh
+       (let* ((logh
                (bigfloat:-
                 (if (bigfloat:zerop tau) 0
                     (bigfloat:+
@@ -1107,7 +1108,7 @@
 (defun adusum (e)
   (push (simplify e) usum))
 
-(defmfun simpsum2 (exp i lo hi)
+(defun simpsum2 (exp i lo hi)
   (prog (*plus *times $simpsum u)
      (setq *plus (list 0) *times 1)
      (when (or (and (eq hi '$inf) (eq lo '$minf))
@@ -1465,7 +1466,7 @@
 	     (subst *i (caddr e) e)))
 	(t (recur-apply #'susum1 e))))
 
-(declare-top (special varlist genvar $factorflag $ratfac *p* *var* *l* *x*))
+(declare-top (special varlist genvar $factorflag $ratfac *p* *var* *x*))
 
 (defmfun $polydecomp (e v)
   (let ((varlist (list v))
