@@ -1,6 +1,9 @@
 ;;Autoloads for maxima
 (in-package :maxima)
 
+($auto_mexpr '$lratsubst "lrats")
+($auto_mexpr '$fullratsubst "lrats")
+
 ($auto_mexpr '$nusum "nusum")
 ($auto_mexpr '$unsum "nusum")
 ($auto_mexpr '$funcsolve "nusum")
@@ -44,6 +47,10 @@
 ($auto_mexpr '$desimp "ode2.mac")
 ($auto_mexpr '$linear2 "ode2")
 
+;villate
+($auto_mexpr '$similaritytransform "eigen.mac")
+($auto_mexpr '$simtran "eigen.mac")
+
 (dolist (v       
 	  '($arite
 	    $card_orbit
@@ -246,7 +253,9 @@
        $cauchy_matrix
        $hessian
        $jacobian
+       $krylov_matrix
        $matrix_sign
+       $sylvester_matrix
        $vandermonde_matrix
        
        $blockmatrixp           ; linalg-utilities.lisp
@@ -257,6 +266,7 @@
        $require_matrix
        $require_nonempty_matrix 
        $require_posinteger
+       $require_real_symmetric_matrix
        $require_selfadjoint_matrix
        $require_square_matrix
        $require_symmetric_matrix
@@ -264,8 +274,8 @@
        $zerofor
        $zeromatrixp
        
-       $get_lu_factors         ; lu.lisp
-       $determinant_by_lu 
+       $determinant_by_lu        ; lu.lisp
+       $get_lu_factors 
        $invert_by_lu 
        $linsolve_by_lu
        $lu_backsub
@@ -278,10 +288,7 @@
        
        $addmatrices            ; mring.lisp
        $require_ring
-       $ringeval
-       
-       $nonnegintegerp         ; polynomialp.lisp
-       $polynomialp ))
+       ))
   (setf (get f 'autoload) "linearalgebra"))
 
 (dolist (mexpr       
@@ -296,18 +303,19 @@
        $hilbert_matrix
        $hipow_gzero
        $kronecker_product
+       $linalg_rank
        $locate_matrix_entry
        $mat_fullunblocker
        $mat_norm
        $mat_trace
        $mat_unblocker
+       $moore_penrose_pseudoinverse
        $nullity
        $nullspace
        $orthogonal_complement
        $polytocompanion
        $ptriangularize
        $ptriangularize_with_proviso
-       $linalg_rank
        $request_rational_matrix
        $require_integer
        $require_symbol
@@ -379,3 +387,14 @@
 
 (defprop $hypergeometric simp-hypergeometric operators)
 (autof 'simp-hypergeometric "hypergeometric")
+
+(dolist (f
+  '($cl_eval
+    $common_lisp    
+    $to_cl))
+  (setf (get f 'autoload) "tocl"))
+
+(dolist (f
+  '($hstep
+    $pwilt))
+  (setf (get f 'autoload) "pwilt"))
